==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Draw/Arc/Arc2PH/ts/Arc2PH_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja_JP">
<context>
    <name>Arc2PH</name>
    <message>
        <location filename="../Arc2PH.js" line="+65"/>
        <source>Start point</source>
        <translation>開始点</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>End point</source>
        <translation>終了点</translation>
    </message>
    <message>
        <location line="+81"/>
        <source>Invalid height</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+7"/>
        <source>The two points are identical</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../Arc2PH.ui" line="+17"/>
        <source>Height:</source>
        <translation>高さ:</translation>
    </message>
    <message>
        <location line="+27"/>
        <source>Direction:</source>
        <translation>向き:</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Counter Clockwise (Positive)</source>
        <translation>反時計回り（正）</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Clockwise (Negative)</source>
        <translation>時計回り（負）</translation>
    </message>
    <message>
        <location filename="../Arc2PHInit.js" line="+2"/>
        <source>2 Points and &amp;Height</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Draw arc from 2 points and height</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Draw/Arc/Arc2PH/ts/Arc2PH_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja">
<context>
    <name>Arc2PH</name>
    <message>
        <location filename="../Arc2PH.js" line="+65"/>
        <source>Start point</source>
        <translation>開始点</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>End point</source>
        <translation>終了点</translation>
    </message>
    <message>
        <location line="+81"/>
        <source>Invalid height</source>
        <translation>無効な高さ</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>The two points are identical</source>
        <translation>２つの点は同じです。</translation>
    </message>
    <message>
        <location filename="../Arc2PH.ui" line="+17"/>
        <source>Height:</source>
        <translation>高さ:</translation>
    </message>
    <message>
        <location line="+27"/>
        <source>Direction:</source>
        <translation>向き:</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Counter Clockwise (Positive)</source>
        <translation>反時計回り（正）</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Clockwise (Negative)</source>
        <translation>時計回り（負）</translation>
    </message>
    <message>
        <location filename="../Arc2PHInit.js" line="+2"/>
        <source>2 Points and &amp;Height</source>
        <translation>２点と高さ</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Draw arc from 2 points and height</source>
        <translation>２点と高さから弧を描く</translation>
    </message>
</context>
</TS>
